<?php

namespace App\Controller;

use App\Repository\ArticleRepository;
use App\Service\FeedService;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\Routing\Attribute\Route;

class FeedController extends AbstractController
{
    public function __construct(
        protected ArticleRepository $articleRepository,
        protected FeedService $feedService,
    )
    {
        
    }

    #[Route('/feed/{type}', name: 'app_feed', requirements: ['type' => 'rss|atom'] )]
    public function feed(
        string $type = FeedService::RSS,
    ): Response
    {
        $articles = $this->articleRepository->findBy(criteria: ['state' => 'published'], orderBy: ['publicationDate' => 'DESC']);

        $feedContent = $this->feedService->createFeed($articles, $this->articleRepository->findLastPublicationDate(), $type);

        $contentType = $type === FeedService::RSS ? 'application/rss+xml' : 'application/atom+xml';

        return new Response($feedContent, Response::HTTP_ACCEPTED, ['Content-Type' => $contentType]);
    }
}